/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Opens a window to view the specified error.
 */
Ext.define( 'QDesk.controller.command.ViewError', {
  extend : 'QDesk.controller.command.BaseCommand',

  requires : [
    'QDesk.ApplicationConfig',
    'QDesk.Msg',

    'QDesk.util.UxUtils',

    'QDesk.view.work.ViewTextWindow'
  ],

  /**
   * Required config property containing the text to view.
   */
  errorText : undefined,

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.errorText )
      Ext.Error.raise( 'Required config parameter missing: errorText' );

    me.callParent( [ config ] );
  },


  execute : function ()
  {
    var me = this;

    me.mask( QDesk.Msg.get( 'QDesk.controller.command.ViewError.maskMsg' ) );

    // give the mask a chance to show up
    Ext.defer( me._viewError, 100, me );
  },


  _viewError : function ()
  {
    var me = this;

    var window = Ext.widget( 'ViewTextWindow', {
      cls : 'viewErrorWindow',
      iconCls : 'windowIcon',
      title : QDesk.Msg.get( 'QDesk.controller.command.ViewError.windowTitle' )
    } );

    window.on( 'afterrender', function ()
    {
      window.maximize();
      window.toFront( false );
    } );

    var viewPanel = window.down( '#viewPanel' );

    var formattedError = me._formatError( me.errorText );
    viewPanel.setHtml( formattedError );

    window.on( 'show', function ()
    {
      me.unmask();

      /*
       * Set focus on the view panel so that the user can immediately use CTRL+A to
       * select all text in the view panel. The delay is used to defer setting of the
       * focus to avoid a known issue (see http://forums.ext.net/showthread.php?3315-CLOSED-Set-Focus-to-textfield-in-logon-window).
       */
      QDesk.util.UxUtils.focus( viewPanel, false );
    } );

    window.show();
  },


  /**
   * Formats the specified error.
   * @param errorText the error text.
   * @return the formatted error text as an HTML string.
   * @private
   */
  _formatError : function ( errorText )
  {
    var textColor = QDesk.ApplicationConfig.get( 'viewError.textColor' );

    var formattedError = '<pre style="margin-bottom: 0; margin-top: 0;">';
    formattedError += '<span style="color: ' + textColor + '">';
    formattedError += Ext.String.htmlEncode( errorText );
    formattedError += '</span>';
    formattedError += '</pre>';

    return formattedError;
  }
} );
