/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Deletes the specified calendar.
 */
Ext.define( 'QDesk.controller.command.scheduler.quartz.calendar.DeleteCalendar', {
  extend : 'QDesk.controller.command.BaseCommand',

  requires : [
    'QDesk.ApplicationConfig',
    'QDesk.Msg',

    'QDesk.util.UxUtils',

    'QDesk.util.constant.ActionUrl',
    'QDesk.util.constant.EventName'
  ],

  /**
   * Required {@link QDesk.ConnectionContext} instance.
   */
  connectionCtx : undefined,

  /**
   * Required config parameter with the job chain to delete.
   */
  calendar : undefined,


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.connectionCtx )
      Ext.Error.raise( 'Required config parameter missing: connectionCtx' );

    if ( !config.calendar )
      Ext.Error.raise( 'Required config parameter missing: calendar' );

    me.callParent( [ config ] );
  },


  execute : function ()
  {
    var me = this;

    if ( QDesk.ApplicationConfig.get( 'quartz.confirm.calendarDelete' ) )
    {
      QDesk.util.UxUtils.showConfirmDialog(
          QDesk.Msg.get( 'QDesk.controller.command.scheduler.quartz.calendar.DeleteCalendar.confirmMsg',
              Ext.String.htmlEncode( me.calendar.get( 'name' ) ) ),
          function ( btn )
          {
            if ( btn == 'yes' )
            {
              me._deleteCalendar();
            }
          }
      );
    }
    else
    {
      me._deleteCalendar();
    }
  },


  /**
   * Deletes the calendar.
   */
  _deleteCalendar : function ()
  {
    var me = this;

    var calendarName = me.calendar.get( 'name' );

    me.mask( QDesk.Msg.get( 'QDesk.controller.command.scheduler.quartz.calendar.DeleteCalendar.maskMsg',
        Ext.String.htmlEncode( calendarName ) ) );

    Ext.Ajax.request( {
      url : QDesk.util.constant.ActionUrl.quartz.calendarActionDelete,
      params : {
        connectionId : me.connectionCtx.getConnectionId(),
        calendarName : calendarName
      },
      callback : function ( opts, success, resp )
      {
        me.unmask();

        if ( success )
        {
          var json = Ext.decode( resp.responseText );
          if ( json.success )
          {
            QDesk.util.UxUtils.showInfo(
                QDesk.Msg.get( 'QDesk.controller.command.scheduler.quartz.calendar.DeleteCalendar.successMsg',
                    Ext.String.htmlEncode( calendarName ) ),
                function ()
                {
                  me.application.fireEvent( QDesk.util.constant.EventName.QUARTZ.CALENDAR_DELETED, {
                    connectionId : me.connectionCtx.getConnectionId(),
                    calendar : me.calendar
                  } );

                  // invoke the success callback handler
                  if ( me.success && Ext.isFunction( me.success ) )
                  {
                    me.success.apply( me );
                  }
                } );
          }
          else
          {
            QDesk.util.UxUtils.showJsonResponseErrors( json, me.failure );
          }
        }
        else
        {
          QDesk.util.UxUtils.showExtJsAjaxError( resp, me.failure );
        }
      }
    } );
  }
} );
