/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Refreshes the Calendars grid in the top-level Calendars tab.
 */
Ext.define( 'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid', {
  extend : 'QDesk.controller.command.BaseCommand',

  requires : [
    'QDesk.controller.command.scheduler.quartz.SchedulerViewUtils',

    'QDesk.util.constant.ActionUrl',
    'QDesk.util.license.LicensedProductFeatures'
  ],

  /**
   * Required {@link QDesk.ConnectionContext} instance.
   */
  connectionCtx : undefined,


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.connectionCtx )
      Ext.Error.raise( 'Required config parameter missing: connectionCtx' );

    me.callParent( [ config ] );
  },


  execute : function ()
  {
    var me = this;

    var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;

    if ( licensedFeatures.Calendars &&
        me.connectionCtx.getJvmAgentInfo().isReady() )
    {
      var calendarsTab = QDesk.controller.command.scheduler.quartz.SchedulerViewUtils.getCalendarsTab(
          me.connectionCtx.getConnectionId() );

      var calendarsGrid = calendarsTab.down( '#calendarsGrid' );

      var calendarsGridStore = calendarsGrid.getStore();

      calendarsGridStore.getProxy().url = QDesk.util.constant.ActionUrl.quartz.calendarActionList;

      var extraStoreParams = {
        connectionId : me.connectionCtx.getConnectionId()
      };

      // // if calendars index enabled, we add the filter query text param
      // if ( me.connectionCtx.getJvmAgentInfo().isQuartzCalendarsIndexEnabled() )
      // {
      //   var filterQueryText = calendarsGrid.down( '#filterQueryText' ).getValue();
      //   if ( !Ext.isEmpty( filterQueryText ) )
      //   {
      //     Ext.apply( extraStoreParams, {
      //       filterQuery : filterQueryText
      //     } );
      //   }
      // }

      calendarsGridStore.getProxy().extraParams = extraStoreParams;

      calendarsGridStore.loadPage( 1, {
        scope : me,
        callback : function ( records, operation, success )
        {
          if ( success )
          {
            // invoke the success callback handler
            if ( me.success && Ext.isFunction( me.success ) )
            {
              me.success.apply( me );
            }
          }
          else
          {
            // invoke the failure callback handler
            if ( me.failure && Ext.isFunction( me.failure ) )
            {
              me.failure.apply( me );
            }
          }
        }
      } );
    }
  }
} );
