/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/**
 * Refreshes the triggers grid in the Triggers tab in the scheduler view panel.
 */
Ext.define( 'QDesk.controller.command.scheduler.quartz.triggers.RefreshTriggersGrid', {
  extend : 'QDesk.controller.command.BaseCommand',

  requires : [
    'QDesk.controller.command.scheduler.quartz.SchedulerViewUtils'
  ],

  /**
   * Required {@link QDesk.ConnectionContext} instance.
   */
  connectionCtx : undefined,


  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.connectionCtx )
      Ext.Error.raise( 'Required config parameter missing: connectionCtx' );

    me.callParent( [ config ] );
  },


  execute : function ()
  {
    var me = this;

    var triggersTab = QDesk.controller.command.scheduler.quartz.SchedulerViewUtils.getTriggersTab(
        me.connectionCtx.getConnectionId() );

    var triggersGrid = triggersTab.down( '#triggersGrid' );
    var filterByTriggerGroupCombo = triggersGrid.down( '#filterByTriggerGroupCombo' );

    var triggersGridStore = triggersGrid.getStore();

    // trigger group selected before the trigger group combo is reloaded
    var selectedTriggerGroup = filterByTriggerGroupCombo.getValue();

    // reloads and resets the job group filter combo and then reloads the jobs grid
    filterByTriggerGroupCombo.getStore().load( {
      scope : me,
      callback : function ( records, operation, success )
      {
        if ( success )
        {
          var extraStoreParams = {
            connectionId : me.connectionCtx.getConnectionId()
          };

          // if triggers index enabled, we add the filter query text param
          if ( me.connectionCtx.getJvmAgentInfo().isQuartzTriggersIndexEnabled() )
          {
            var filterQueryText = triggersGrid.down( '#filterQueryText' ).getValue();
            if ( !Ext.isEmpty( filterQueryText ) )
            {
              Ext.apply( extraStoreParams, {
                filterQuery : filterQueryText
              } );
            }
          }

          triggersGridStore.clearFilter( true );

          // check the selected trigger group is still present in the list of reloaded trigger groups and if so,
          // add it as a filter
          if ( selectedTriggerGroup != null )
          {
            var selectedTriggerGroupRecord = filterByTriggerGroupCombo.getStore().findRecord( 'name',
                selectedTriggerGroup );
            if ( selectedTriggerGroupRecord )
            {
              // the previously selected trigger group is still present after the trigger group store has been reloaded
              triggersGridStore.addFilter( [
                Ext.create( 'Ext.util.Filter', {
                  property : 'trigger.group.name',
                  value : selectedTriggerGroup
                } )
              ], false );
            }
          }

          triggersGridStore.getProxy().extraParams = extraStoreParams;

          // no need to reset the combo, just reload the grid
          triggersGridStore.loadPage( 1, {
            scope : me,
            callback : function ( records, operation, success )
            {
              if ( success )
              {
                // invoke the success callback handler
                if ( me.success && Ext.isFunction( me.success ) )
                {
                  me.success.apply( me );
                }
              }
              else
              {
                // invoke the failure callback handler
                if ( me.failure && Ext.isFunction( me.failure ) )
                {
                  me.failure.apply( me );
                }
              }
            }
          } );
        }
        else
        {
          // invoke the failure callback handler
          if ( me.failure && Ext.isFunction( me.failure ) )
          {
            me.failure.apply( me );
          }
        }
      }
    } );
  }
} );
