/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.store.enums.MessageChannelStore', {
  extend : 'Ext.data.Store',

  requires : [
    'QDesk.model.message.channel.MessageChannel',

    'QDesk.util.EnumUtils'
  ],

  storeId : 'enums.MessageChannelStore',

  fields : [ 'value', 'valueLabel' ],

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      data : [
        /* Collaboration message channels */
        {
          value : QDesk.model.message.channel.MessageChannel.COLLABORATION_HIPCHAT,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.COLLABORATION_HIPCHAT )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.COLLABORATION_SLACK,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.COLLABORATION_SLACK )
        },


        /* Email message channel */
        {
          value : QDesk.model.message.channel.MessageChannel.EMAIL,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName( QDesk.model.message.channel.MessageChannel.EMAIL )
        },


        /* Incident management message channels */
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_ALERTOPS,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_ALERTOPS )
        },
        // {
        //   value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_DYNATRACE,
        //   valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
        //       QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_DYNATRACE )
        // },
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_FRESHSERVICE,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_FRESHSERVICE )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_JIRA,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_JIRA )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_OPSGENIE,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_OPSGENIE )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_PAGERDUTY,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_PAGERDUTY )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SPLUNK,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SPLUNK )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SQUADCAST,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SQUADCAST )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_XMATTERS,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_XMATTERS )
        },


        /* IM message channels */
        {
          value : QDesk.model.message.channel.MessageChannel.IM_XMPP,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName( QDesk.model.message.channel.MessageChannel.IM_XMPP )
        },


        /* SMS message channels */
        {
          value : QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_CENTRAL,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_CENTRAL )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_PLATFORM,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_PLATFORM )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.SMS_CLOCKWORK,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SMS_CLOCKWORK )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.SMS_SMSGLOBAL,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SMS_SMSGLOBAL )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.SMS_TWILIO,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SMS_TWILIO )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.SMS_VONAGE,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SMS_VONAGE )
        },


        /* SNMP message channels */
        {
          value : QDesk.model.message.channel.MessageChannel.SNMPV1_TRAP,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SNMPV1_TRAP )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.SNMPV2C_TRAP,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SNMPV2C_TRAP )
        },
        {
          value : QDesk.model.message.channel.MessageChannel.SNMPV3_TRAP,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.SNMPV3_TRAP )
        },


        /* Web Service message channel */
        {
          value : QDesk.model.message.channel.MessageChannel.WEB_SERVICE,
          valueLabel : QDesk.util.EnumUtils.getMessageChannelName(
              QDesk.model.message.channel.MessageChannel.WEB_SERVICE )
        }
      ]
    } );

    me.callParent( [ config ] );
  }
} );