/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.store.scheduler.quartz.QuartzCalendarNameStore', {
  extend : 'Ext.data.Store',

  requires : [
    'QDesk.util.constant.ActionUrl'
  ],

  fields : [ 'name' ],

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      proxy : {
        type : 'ajax',

        url : QDesk.util.constant.ActionUrl.quartz.calendarActionListNames,

        reader : {
          type : 'json',
          rootProperty : 'data',
          idProperty : 'name',
          successProperty : 'success',
          /*
           * Transform function to turn a list of calendar names onto a list of objects with the following structure:
           * {
           *   name : calendarName
           * }
           */
          transform : function ( data )
          {
            var key = this.getRootProperty();
            data[ key ] = data[ key ].map(
                function ( val )
                {
                  return { name : val };
                } );
            return data;
          }
        },

        // Don't want to include these params in request
        pageParam : undefined,
        startParam : undefined,
        limitParam : undefined,
        sortParam : undefined,
        directionParam : undefined,
        filterParam : undefined,
        groupParam : undefined
      }
    } );

    me.callParent( [ config ] );
  }
} );
