/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel', {
  extend : 'Ext.tree.Panel',

  requires : [
    'QDesk.Msg',

    'QDesk.model.message.channel.MessageChannel',
    'QDesk.model.security.Permission',

    'QDesk.store.message.MessageChannelProfilesTreeStore',

    'QDesk.util.EnumUtils',
    'QDesk.util.constant.Const'
  ],

  alias : 'widget.MessageChannelProfilesTreePanel',

  cls : 'messageChannelProfilesTreePanel',

  //scrollable : true,

  displayField : 'name',

  rootVisible : true,

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      root : {
        id : QDesk.util.constant.Const.MESSAGE_CHANNEL_PROFILES_ROOT_ID,  // ROOT folder ID
        folderId : QDesk.util.constant.Const.MESSAGE_CHANNEL_PROFILES_ROOT_FOLDER_ID,
        name : QDesk.Msg.get( 'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.rootNodeName' ),
        expanded : true,

        /* MessageChannelProfilesTreeNode */
        nodeType : 'folder'
      },

      viewConfig : {
        copy : false,

        plugins : {
          ptype : 'treeviewdragdrop',
          appendOnly : true,
          dragText : QDesk.Msg.get( 'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.dragText' )
        }
      },

      store : Ext.create( 'QDesk.store.message.MessageChannelProfilesTreeStore' ),

      dockedItems : [
        {
          xtype : 'toolbar',
          itemId : 'toolBar',
          dock : 'top',
          items : [
            {
              xtype : 'button',
              itemId : 'refreshButton',
              scale : 'small',
              iconCls : 'refresh',
              tooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.tooltipRefreshButton' ),
              disabled : true,
              qdRequiresAnyPermissions : [],
              qdNotAuthorizedIconCls : 'refreshNAUTH'
            },
            {
              xtype : 'button',
              itemId : 'collapseAllButton',
              scale : 'small',
              iconCls : 'collapseAll',
              tooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.tooltipCollapseAllButton' ),
              disabled : true
            },
            '-',
            {
              xtype : 'button',
              itemId : 'addFolderOrProfileButton',
              scale : 'small',
              iconCls : 'addFolderOrProfile',
              tooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.tooltipAddFolderOrProfileButton' ),
              disabled : true,
              qdRequiresAnyPermissions : [
                QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_FLD_ADD,
                QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD
              ],
              qdNotAuthorizedIconCls : 'addFolderOrProfileNAUTH',
              menu : {
                xtype : 'menu',
                ignoreParentClicks : true,
                items : [
                  {
                    itemId : 'addFolderButton',
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addFolderButton' ),
                    iconCls : 'addFolder',
                    qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_FLD_ADD ],
                    qdNotAuthorizedIconCls : 'addFolderNAUTH'
                  },
                  '-',
                  {
                    itemId : 'addEmailProfileButton',
                    text : QDesk.util.EnumUtils.getMessageChannelName(
                        QDesk.model.message.channel.MessageChannel.EMAIL ),
                    iconCls : QDesk.model.message.channel.MessageChannel.EMAIL,
                    qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                    qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.EMAIL + '_NAUTH'
                  },

                  /*
                   * Collaboration message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addCollaborationProfileGroup' ),
                    iconCls : 'addCollaborationProfile',
                    menu : [
                      {
                        itemId : 'addCollaborationHipChatProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.COLLABORATION_HIPCHAT ),
                        iconCls : QDesk.model.message.channel.MessageChannel.COLLABORATION_HIPCHAT,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.COLLABORATION_HIPCHAT +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addCollaborationSlackProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.COLLABORATION_SLACK ),
                        iconCls : QDesk.model.message.channel.MessageChannel.COLLABORATION_SLACK,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.COLLABORATION_SLACK +
                            '_NAUTH'
                      }
                    ]
                  },

                  /*
                   * Incident management message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addIncidentManagementMessageProfileGroup' ),
                    iconCls : 'addIncidentManagementMessageProfile',
                    menu : [
                      {
                        itemId : 'addIncidentMgmtAlertOpsProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_ALERTOPS ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_ALERTOPS,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_ALERTOPS +
                            '_NAUTH'
                      },
                      // {
                      //   itemId : 'addIncidentMgmtDynatraceProfileButton',
                      //   text : QDesk.util.EnumUtils.getMessageChannelName(
                      //       QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_DYNATRACE ),
                      //   iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_DYNATRACE,
                      //   qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                      //   qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_DYNATRACE +
                      //       '_NAUTH'
                      // },
                      {
                        itemId : 'addIncidentMgmtFreshserviceProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_FRESHSERVICE ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_FRESHSERVICE,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_FRESHSERVICE +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addIncidentMgmtJiraProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_JIRA ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_JIRA,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_JIRA +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addIncidentMgmtOpsGenieProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_OPSGENIE ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_OPSGENIE,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_OPSGENIE +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addIncidentMgmtPagerDutyProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_PAGERDUTY ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_PAGERDUTY,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_PAGERDUTY +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addIncidentMgmtSplunkProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SPLUNK ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SPLUNK,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SPLUNK +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addIncidentMgmtSquadcastProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SQUADCAST ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SQUADCAST,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_SQUADCAST +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addIncidentMgmtXMattersProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_XMATTERS ),
                        iconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_XMATTERS,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.INCIDENT_MGMT_XMATTERS +
                            '_NAUTH'
                      }
                    ]
                  },

                  /*
                   * Instant message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addInstantMessageProfileGroup' ),
                    iconCls : 'addInstantMessageProfile',
                    menu : [
                      {
                        itemId : 'addImXmppProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.IM_XMPP ),
                        iconCls : QDesk.model.message.channel.MessageChannel.IM_XMPP,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.IM_XMPP + '_NAUTH'
                      }
                    ]
                  },

                  /*
                   * SMS message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addSmsProfileGroup' ),
                    iconCls : 'addSmsProfile',
                    menu : [
                      {
                        itemId : 'addSmsClickatellCentralProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_CENTRAL ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_CENTRAL,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_CENTRAL +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addSmsClickatellPlatformProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_PLATFORM ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_PLATFORM,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SMS_CLICKATELL_PLATFORM +
                            '_NAUTH'
                      },
                      {
                        itemId : 'addSmsClockworkProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SMS_CLOCKWORK ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SMS_CLOCKWORK,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SMS_CLOCKWORK + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsSmsGlobalProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SMS_SMSGLOBAL ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SMS_SMSGLOBAL,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SMS_SMSGLOBAL + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsTwilioProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SMS_TWILIO ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SMS_TWILIO,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SMS_TWILIO + '_NAUTH'
                      },
                      {
                        itemId : 'addSmsVonageProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SMS_VONAGE ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SMS_VONAGE,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SMS_VONAGE + '_NAUTH'
                      }
                    ]
                  },

                  /*
                   * SNMP trap message channel profiles.
                   */
                  {
                    text : QDesk.Msg.get(
                        'QDesk.view.work.message.channel.MessageChannelProfilesTreePanel.addSnmpProfileGroup' ),
                    iconCls : 'addSnmpProfile',
                    menu : [
                      {
                        itemId : 'addSnmpV1TrapProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SNMPV1_TRAP ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SNMPV1_TRAP,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SNMPV1_TRAP + '_NAUTH'
                      },
                      {
                        itemId : 'addSnmpV2cTrapProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SNMPV2C_TRAP ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SNMPV2C_TRAP,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SNMPV2C_TRAP + '_NAUTH'
                      },
                      {
                        itemId : 'addSnmpV3TrapProfileButton',
                        text : QDesk.util.EnumUtils.getMessageChannelName(
                            QDesk.model.message.channel.MessageChannel.SNMPV3_TRAP ),
                        iconCls : QDesk.model.message.channel.MessageChannel.SNMPV3_TRAP,
                        qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                        qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.SNMPV3_TRAP + '_NAUTH'
                      }
                    ]
                  },

                  /*
                   *  Web service message channel profile.
                   */
                  {
                    itemId : 'addWebServiceProfileButton',
                    text : QDesk.util.EnumUtils.getMessageChannelName(
                        QDesk.model.message.channel.MessageChannel.WEB_SERVICE ),
                    iconCls : QDesk.model.message.channel.MessageChannel.WEB_SERVICE,
                    qdRequiresAnyPermissions : [ QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_ADD ],
                    qdNotAuthorizedIconCls : QDesk.model.message.channel.MessageChannel.WEB_SERVICE + '_NAUTH'
                  }
                ]
              }
            },
            {
              xtype : 'button',
              itemId : 'deleteFolderOrProfileButton',
              scale : 'small',
              iconCls : 'deleteFolderOrProfile',
              // no tooltip, it is set dynamically based on the selection (folder / profile)
              disabled : true,
              qdRequiresAnyPermissions : [
                QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_FLD_DELETE,
                QDesk.model.security.Permission.MSG_CHANNEL_PROFILE_DELETE
              ],
              qdNotAuthorizedIconCls : 'deleteFolderOrProfileNAUTH'
            }
          ]
        }
      ]
    } );

    me.callParent( [ config ] );

    // column's inner renderer that HTML-encodes values displayed in the tree
    me.getColumns()[ 0 ].innerRenderer = function ( value, metaData, record, rowIdx, colIdx, store, view )
    {
      return Ext.String.htmlEncode( value );
    };
  }
} );
