/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel', {
  extend : 'Ext.panel.Panel',

  requires : [
    'QDesk.Msg',
    'QDesk.Properties',

    'QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity',

    'QDesk.util.EnumUtils'
  ],

  alias : 'widget.IncidentMgmtAlertOpsBasicPanel',

  border : false,

  layout : 'anchor',

  defaults : {
    anchor : '100%',
    labelWidth : 110
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      title : QDesk.Msg.get(
          'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.tabLabelBasic' ),

      items : [
        {
          xtype : 'textfield',
          itemId : 'integrationUrl',
          name : 'integrationUrl',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldLabelIntegrationUrl' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldTooltipIntegrationUrl' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldEmptyTxtIntegrationUrl' ),
          allowBlank : false,
          maxLength : 128,
          vtype : 'url',
          qdesk : {
            required : true
          }
        },

        // {
        //   xtype : 'textfield',
        //   itemId : 'apiKey',
        //   name : 'apiKey',
        //   fieldLabel : QDesk.Msg.get(
        //       'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldLabelApiKey' ),
        //   fieldTooltip : QDesk.Msg.get(
        //       'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldTooltipApiKey' ),
        //   emptyText : QDesk.Msg.get(
        //       'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldEmptyTxtApiKey' ),
        //   allowBlank : false,
        //   maxLength : 128,
        //   qdesk : {
        //     required : true
        //   }
        // },

        // incident properties
        {
          xtype : 'fieldset',
          title : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldsetLabelMessageProperties' ),
          tooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldsetTooltipMessageProperties' ),
          padding : '5 5 0 5',
          defaults : {
            anchor : '100%',
            labelWidth : 105
          },
          items : [
            {
              xtype : 'textfield',
              itemId : 'source',
              name : 'source',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldLabelSource' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldTooltipSource' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldEmptyTxtSource' ),
              allowBlank : false,
              maxLength : 100,
              qdesk : {
                required : true
              }
            },

            {
              xtype : 'combo',
              itemId : 'severity',
              name : 'severity',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldLabelSeverity' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldTooltipSeverity' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.alertops.AlertOpsBasicPanel.fieldEmptyTxtSeverity' ),
              anchor : '60%',
              value : '',
              editable : false,
              forceSelection : true,
              queryMode : 'local',
              store : new Ext.data.ArrayStore( {
                fields : [
                  'value',
                  'valueLabel'
                ],
                data : [
                  [ QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.INFO,
                    QDesk.util.EnumUtils.getAlertOpsSeverityName(
                        QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.INFO ) ],
                  [ QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.WARNING,
                    QDesk.util.EnumUtils.getAlertOpsSeverityName(
                        QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.WARNING ) ],
                  [ QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.ERROR,
                    QDesk.util.EnumUtils.getAlertOpsSeverityName(
                        QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.ERROR ) ],
                  [ QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.CRITICAL,
                    QDesk.util.EnumUtils.getAlertOpsSeverityName(
                        QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.CRITICAL ) ]
                ]
              } ),
              valueField : 'value',
              displayField : 'valueLabel',
              allowBlank : false,
              maxLength : 10,
              qdesk : {
                required : true
              }
            }
          ]
        }
      ]
    } );

    me.callParent( [ config ] );
  },


  initComponent : function ()
  {
    var me = this;

    me.callParent();

    // set default alert severity
    var severityCombo = me.down( '#severity' );
    severityCombo.setValue( QDesk.model.message.channel.incident_mgmt.AlertOpsSeverity.INFO );
  }
} );
