/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel', {
  extend : 'Ext.panel.Panel',

  requires : [
    'QDesk.Msg',
    'QDesk.Properties',

    'QDesk.model.message.channel.incident_mgmt.PagerDutySeverity',

    'QDesk.util.EnumUtils'
  ],

  alias : 'widget.IncidentMgmtPagerDutyBasicPanel',

  border : false,

  layout : 'anchor',

  defaults : {
    anchor : '100%',
    labelWidth : 110
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      title : QDesk.Msg.get(
          'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.tabLabelBasic' ),

      items : [
        {
          xtype : 'textfield',
          itemId : 'integrationKey',
          name : 'integrationKey',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldLabelIntegrationKey' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldTooltipIntegrationKey' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldEmptyTxtIntegrationKey' ),
          allowBlank : false,
          maxLength : 32,
          qdesk : {
            required : true
          }
        },

        // alert properties
        {
          xtype : 'fieldset',
          title : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldsetLabelAlertProperties' ),
          tooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldsetTooltipAlertProperties' ),
          padding : '5 5 0 5',
          defaults : {
            anchor : '100%',
            labelWidth : 85
          },
          items : [
            {
              xtype : 'textfield',
              itemId : 'source',
              name : 'source',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldLabelSource' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldTooltipSource' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldEmptyTxtSource' ),
              allowBlank : false,
              maxLength : 100,
              qdesk : {
                required : true
              }
            },

            {
              xtype : 'combo',
              itemId : 'severity',
              name : 'severity',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldLabelSeverity' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldTooltipSeverity' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldEmptyTxtSeverity' ),
              anchor : '60%',
              value : '',
              editable : false,
              forceSelection : true,
              queryMode : 'local',
              store : new Ext.data.ArrayStore( {
                fields : [
                  'value',
                  'valueLabel'
                ],
                data : [
                  [ QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.INFO,
                    QDesk.util.EnumUtils.getPagerDutySeverityName(
                        QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.INFO ) ],
                  [ QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.WARNING,
                    QDesk.util.EnumUtils.getPagerDutySeverityName(
                        QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.WARNING ) ],
                  [ QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.ERROR,
                    QDesk.util.EnumUtils.getPagerDutySeverityName(
                        QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.ERROR ) ],
                  [ QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.CRITICAL,
                    QDesk.util.EnumUtils.getPagerDutySeverityName(
                        QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.CRITICAL ) ]
                ]
              } ),
              valueField : 'value',
              displayField : 'valueLabel',
              allowBlank : false,
              maxLength : 10,
              qdesk : {
                required : true
              }
            },

            {
              xtype : 'textfield',
              itemId : 'component',
              name : 'component',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldLabelComponent' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldTooltipComponent' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldEmptyTxtComponent' ),
              allowBlank : true,
              maxLength : 100,
              qdesk : {
                required : false
              }
            },

            {
              xtype : 'textfield',
              itemId : 'group',
              name : 'group',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldLabelGroup' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldTooltipGroup' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldEmptyTxtGroup' ),
              allowBlank : true,
              maxLength : 100,
              qdesk : {
                required : false
              }
            },

            {
              xtype : 'textfield',
              itemId : 'clazz',
              name : 'clazz',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldLabelClazz' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldTooltipClazz' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.pagerduty.PagerDutyBasicPanel.fieldEmptyTxtClazz' ),
              allowBlank : true,
              maxLength : 100,
              qdesk : {
                required : false
              }
            }
          ]
        }
      ]
    } );

    me.callParent( [ config ] );
  },


  initComponent : function ()
  {
    var me = this;

    me.callParent();

    // set default alert severity
    var severityCombo = me.down( '#severity' );
    severityCombo.setValue( QDesk.model.message.channel.incident_mgmt.PagerDutySeverity.INFO );
  }
} );
