/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel', {
  extend : 'Ext.panel.Panel',

  requires : [
    'QDesk.Msg',
    'QDesk.Properties',

    'QDesk.model.message.channel.incident_mgmt.SplunkSeverity',

    'QDesk.util.EnumUtils'
  ],

  alias : 'widget.IncidentMgmtSplunkBasicPanel',

  border : false,

  layout : 'anchor',

  defaults : {
    anchor : '100%',
    labelWidth : 90
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      title : QDesk.Msg.get(
          'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.tabLabelBasic' ),

      items : [
        {
          xtype : 'textfield',
          itemId : 'eventCollectorUrl',
          name : 'eventCollectorUrl',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldLabelEventCollectorUrl' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldTooltipEventCollectorUrl' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldEmptyTxtEventCollectorUrl' ),
          allowBlank : false,
          maxLength : 128,
          vtype : 'url',
          qdesk : {
            required : true
          }
        },

        {
          xtype : 'textfield',
          itemId : 'eventCollectorToken',
          name : 'eventCollectorToken',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldLabelEventCollectorToken' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldTooltipEventCollectorToken' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldEmptyTxtEventCollectorToken' ),
          allowBlank : false,
          maxLength : 36,
          qdesk : {
            required : true
          }
        },

        // event properties
        {
          xtype : 'fieldset',
          title : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldsetLabelEventProperties' ),
          tooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldsetTooltipEventProperties' ),
          padding : '5 5 0 5',
          defaults : {
            anchor : '100%',
            labelWidth : 85
          },
          items : [
            {
              xtype : 'textfield',
              itemId : 'source',
              name : 'source',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldLabelSource' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldTooltipSource' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldEmptyTxtSource' ),
              allowBlank : true,
              maxLength : 100,
              qdesk : {
                required : false
              }
            },

            {
              xtype : 'combo',
              itemId : 'severity',
              name : 'severity',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldLabelSeverity' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldTooltipSeverity' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldEmptyTxtSeverity' ),
              anchor : '60%',
              value : '',
              editable : false,
              forceSelection : true,
              queryMode : 'local',
              store : new Ext.data.ArrayStore( {
                fields : [
                  'value',
                  'valueLabel'
                ],
                data : [
                  [ QDesk.model.message.channel.incident_mgmt.SplunkSeverity.INFO,
                    QDesk.util.EnumUtils.getSplunkSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SplunkSeverity.INFO ) ],
                  [ QDesk.model.message.channel.incident_mgmt.SplunkSeverity.WARNING,
                    QDesk.util.EnumUtils.getSplunkSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SplunkSeverity.WARNING ) ],
                  [ QDesk.model.message.channel.incident_mgmt.SplunkSeverity.ERROR,
                    QDesk.util.EnumUtils.getSplunkSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SplunkSeverity.ERROR ) ],
                  [ QDesk.model.message.channel.incident_mgmt.SplunkSeverity.CRITICAL,
                    QDesk.util.EnumUtils.getSplunkSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SplunkSeverity.CRITICAL ) ]
                ]
              } ),
              valueField : 'value',
              displayField : 'valueLabel',
              allowBlank : false,
              maxLength : 10,
              qdesk : {
                required : true
              }
            },

            {
              xtype : 'textfield',
              itemId : 'index',
              name : 'index',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldLabelIndex' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldTooltipIndex' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldEmptyTxtIndex' ),
              allowBlank : true,
              maxLength : 100,
              qdesk : {
                required : false
              }
            },

            {
              xtype : 'textfield',
              itemId : 'channelId',
              name : 'channelId',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldLabelChannelId' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldTooltipChannelId' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.splunk.SplunkBasicPanel.fieldEmptyTxtChannelId' ),
              allowBlank : true,
              maxLength : 100,
              qdesk : {
                required : false
              }
            }
          ]
        }
      ]
    } );

    me.callParent( [ config ] );
  },


  initComponent : function ()
  {
    var me = this;

    me.callParent();

    // set default alert severity
    var severityCombo = me.down( '#severity' );
    severityCombo.setValue( QDesk.model.message.channel.incident_mgmt.SplunkSeverity.INFO );
  }
} );
