/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel', {
  extend : 'Ext.panel.Panel',

  requires : [
    'QDesk.Msg',
    'QDesk.Properties',

    'QDesk.model.message.channel.incident_mgmt.SquadcastSeverity',

    'QDesk.util.EnumUtils'
  ],

  alias : 'widget.IncidentMgmtSquadcastBasicPanel',

  border : false,

  layout : 'anchor',

  defaults : {
    anchor : '100%',
    labelWidth : 100
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      title : QDesk.Msg.get(
          'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.tabLabelBasic' ),

      items : [
        {
          xtype : 'textfield',
          itemId : 'webhookUrl',
          name : 'webhookUrl',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldLabelWebhookUrl' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldTooltipWebhookUrl' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldEmptyTxtWebhookUrl' ),
          allowBlank : false,
          maxLength : 128,
          vtype : 'url',
          qdesk : {
            required : true
          }
        },

        // incident properties
        {
          xtype : 'fieldset',
          title : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldsetLabelIncidentProperties' ),
          tooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldsetTooltipIncidentProperties' ),
          padding : '5 5 0 5',
          defaults : {
            anchor : '100%',
            labelWidth : 70
          },
          items : [
            {
              xtype : 'textfield',
              itemId : 'source',
              name : 'source',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldLabelSource' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldTooltipSource' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldEmptyTxtSource' ),
              allowBlank : false,
              maxLength : 100,
              qdesk : {
                required : true
              }
            },

            {
              xtype : 'combo',
              itemId : 'severity',
              name : 'severity',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldLabelSeverity' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldTooltipSeverity' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.squadcast.SquadcastBasicPanel.fieldEmptyTxtSeverity' ),
              anchor : '60%',
              value : '',
              editable : false,
              forceSelection : true,
              queryMode : 'local',
              store : new Ext.data.ArrayStore( {
                fields : [
                  'value',
                  'valueLabel'
                ],
                data : [
                  [ QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.INFO,
                    QDesk.util.EnumUtils.getSquadcastSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.INFO ) ],
                  [ QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.WARNING,
                    QDesk.util.EnumUtils.getSquadcastSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.WARNING ) ],
                  [ QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.ERROR,
                    QDesk.util.EnumUtils.getSquadcastSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.ERROR ) ],
                  [ QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.CRITICAL,
                    QDesk.util.EnumUtils.getSquadcastSeverityName(
                        QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.CRITICAL ) ]
                ]
              } ),
              valueField : 'value',
              displayField : 'valueLabel',
              allowBlank : false,
              maxLength : 10,
              qdesk : {
                required : true
              }
            }
          ]
        }
      ]
    } );

    me.callParent( [ config ] );
  },


  initComponent : function ()
  {
    var me = this;

    me.callParent();

    // set default alert severity
    var severityCombo = me.down( '#severity' );
    severityCombo.setValue( QDesk.model.message.channel.incident_mgmt.SquadcastSeverity.INFO );
  }
} );
