/*
 * Copyright (c) 2013-2024 QuartzDesk.com. All Rights Reserved.
 * QuartzDesk.com PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

Ext.define( 'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel', {
  extend : 'Ext.panel.Panel',

  requires : [
    'QDesk.Msg',
    'QDesk.Properties',

    'QDesk.model.message.channel.incident_mgmt.XMattersPriority',

    'QDesk.util.EnumUtils'
  ],

  alias : 'widget.IncidentMgmtXMattersBasicPanel',

  border : false,

  layout : 'anchor',

  defaults : {
    anchor : '100%',
    labelWidth : 110
  },

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    Ext.apply( config, {
      title : QDesk.Msg.get(
          'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.tabLabelBasic' ),

      items : [
        {
          xtype : 'textfield',
          itemId : 'integrationUrl',
          name : 'integrationUrl',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldLabelIntegrationUrl' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldTooltipIntegrationUrl' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldEmptyTxtIntegrationUrl' ),
          allowBlank : false,
          maxLength : 256,
          vtype : 'url',
          qdesk : {
            required : true
          }
        },

        {
          xtype : 'textfield',
          itemId : 'username',
          name : 'username',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldLabelUsername' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldTooltipUsername' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldEmptyTxtUsername' ),
          allowBlank : false,
          maxLength : 64,
          qdesk : {
            required : true
          }
        },

        {
          xtype : 'textfield',
          inputType : 'password',
          itemId : 'password',
          name : 'password',
          fieldLabel : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldLabelPassword' ),
          fieldTooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldTooltipPassword' ),
          emptyText : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldEmptyTxtPassword' ),
          allowBlank : false,
          maxLength : 64,
          qdesk : {
            required : true
          }
        },

        // incident properties
        {
          xtype : 'fieldset',
          title : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldsetLabelAlertProperties' ),
          tooltip : QDesk.Msg.get(
              'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldsetTooltipAlertProperties' ),
          padding : '5 5 0 5',
          defaults : {
            anchor : '100%',
            labelWidth : 70
          },
          items : [
            {
              xtype : 'textfield',
              itemId : 'source',
              name : 'source',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldLabelSource' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldTooltipSource' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldEmptyTxtSource' ),
              allowBlank : false,
              maxLength : 100,
              qdesk : {
                required : true
              }
            },

            {
              xtype : 'combo',
              itemId : 'priority',
              name : 'priority',
              fieldLabel : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldLabelPriority' ),
              fieldTooltip : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldTooltipPriority' ),
              emptyText : QDesk.Msg.get(
                  'QDesk.view.work.message.channel.incident_mgmt.xmatters.XMattersBasicPanel.fieldEmptyTxtPriority' ),
              anchor : '60%',
              value : '',
              editable : false,
              forceSelection : true,
              queryMode : 'local',
              store : new Ext.data.ArrayStore( {
                fields : [
                  'value',
                  'valueLabel'
                ],
                data : [
                  [ QDesk.model.message.channel.incident_mgmt.XMattersPriority.LOW,
                    QDesk.util.EnumUtils.getXMattersPriorityName(
                        QDesk.model.message.channel.incident_mgmt.XMattersPriority.LOW ) ],
                  [ QDesk.model.message.channel.incident_mgmt.XMattersPriority.MEDIUM,
                    QDesk.util.EnumUtils.getXMattersPriorityName(
                        QDesk.model.message.channel.incident_mgmt.XMattersPriority.MEDIUM ) ],
                  [ QDesk.model.message.channel.incident_mgmt.XMattersPriority.HIGH,
                    QDesk.util.EnumUtils.getXMattersPriorityName(
                        QDesk.model.message.channel.incident_mgmt.XMattersPriority.HIGH ) ]
                ]
              } ),
              valueField : 'value',
              displayField : 'valueLabel',
              allowBlank : false,
              maxLength : 10,
              qdesk : {
                required : true
              }
            }
          ]
        }
      ]
    } );

    me.callParent( [ config ] );
  },


  initComponent : function ()
  {
    var me = this;

    me.callParent();

    // // set default alert priority
    var priorityCombo = me.down( '#priority' );
    priorityCombo.setValue( QDesk.model.message.channel.incident_mgmt.XMattersPriority.MEDIUM );
  }
} );
