Ext.define( 'QDesk.view.work.scheduler.quartz.calendar.CalendarsGridController', {
  extend : 'Ext.app.ViewController',

  requires : [
    'QDesk.Msg',

    'QDesk.util.UxUtils',
    'QDesk.util.license.LicensedProductFeatures'
  ],

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.qdesk )
      Ext.Error.raise( 'Required config parameter missing: qdesk' );

    if ( !config.qdesk.connectionCtx )
      Ext.Error.raise( 'Required config parameter missing: qdesk.connectionCtx' );

    me.callParent( [ config ] );
  },

  init : function ()
  {
    var me = this;

    // CalendarsGrid
    var grid = me.getView();

    me._bindEventHandlers( grid );

    me.callParent();
  },


  /**
   * Binds the Calendars grid events to their handlers.
   */
  _bindEventHandlers : function ( grid )
  {
    var me = this;

    var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;

    var connectionCtx = me.qdesk.connectionCtx;
    var jvmAgentInfo = connectionCtx.getJvmAgentInfo();
    var schedulerInfo = connectionCtx.getSchedulerInfo();

    // var schedulerVersion = schedulerInfo.getSchedulerVersion();
    var jvmAgentReady = jvmAgentInfo.isReady();
    // var publicApiReady = schedulerInfo.isPublicApiReady();

    if ( licensedFeatures.Calendars && jvmAgentReady )
    {
      grid.on( 'selectionchange', function ( selectionModel, selectedRecords )
      {
        if ( selectedRecords.length == 0 )
        {
          me._onCalendarUnselected( grid );
        }
        else
        {
          me._onCalendarSelected( selectedRecords[ 0 ], grid );
        }
      } );

      // var filterQueryText = grid.down( '#filterQueryText' );

      // var calendarsIndexEnabled = jvmAgentInfo.isQuartzCalendarsIndexEnabled();
      //
      // if ( !calendarsIndexEnabled )
      // {
      //   filterQueryText.setEmptyText(
      //       QDesk.Msg.get(
      //           'QDesk.view.work.scheduler.quartz.calendar.CalendarsGridController.calendarsIndexDisabledEmptyText' ) );
      // }

      grid.getStore().on( 'beforeload',
          function ( store, operation )
          {
            grid.down( '#refreshButton' ).disable();
            grid.down( '#addButton' ).disable();
            grid.down( '#deleteButton' ).disable();
            grid.down( '#editButton' ).disable();
            grid.down( '#cloneButton' ).disable();
            grid.down( '#viewAuditTrailButton' ).disable();
            // filterQueryText.disable();

            /*
             * FIXME: ExtJS 4.2 does not trigger selectionchange when a grid's store is reloaded.
             * Therefore we need to force-fire this event by clearing the selection.
             */
            grid.getSelectionModel().deselectAll();
          } );

      grid.getStore().on( 'load',
          function ( store, records, successful, operation )
          {
            grid.down( '#refreshButton' ).enable();

            // // enable only if the calendars index is enabled in the agent
            // if ( calendarsIndexEnabled )
            // {
            //   filterQueryText.enable();
            // }

            if ( successful )
            {
              grid.down( '#addButton' ).enable();
            }
            else
            {
              store.removeAll();

              QDesk.util.UxUtils.showExtJsOperationError( operation );
            }
          } );
    }
  },


  /**
   * Invoked when a calendar record in the CalendarsGrid is selected.
   * @param calendar a QDesk.model.scheduler.quartz.QuartzCalendar instance representing the selected
   * calendar.
   * @param grid the calendars grid.
   */
  _onCalendarSelected : function ( calendar, grid )
  {
    var me = this;

    grid.down( '#deleteButton' ).enable();
    grid.down( '#editButton' ).enable();
    grid.down( '#cloneButton' ).enable();
    grid.down( '#viewAuditTrailButton' ).enable();
  },


  /**
   * Invoked when a calendar record in the CalendarsGrid is unselected.
   * @param grid the calendars grid.
   */
  _onCalendarUnselected : function ( grid )
  {
    var me = this;

    grid.down( '#deleteButton' ).disable();
    grid.down( '#editButton' ).disable();
    grid.down( '#cloneButton' ).disable();
    grid.down( '#viewAuditTrailButton' ).disable();
  }
} );