Ext.define( 'QDesk.view.work.scheduler.quartz.calendar.CalendarsTabController', {
  extend : 'Ext.app.ViewController',

  requires : [
    // 'QDesk.controller.command.scheduler.quartz.calendar.AddCalendar',
    // 'QDesk.controller.command.scheduler.quartz.calendar.CloneCalendar',
    // 'QDesk.controller.command.scheduler.quartz.calendar.DeleteCalendar',
    // 'QDesk.controller.command.scheduler.quartz.calendar.EditCalendar',
    'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid',
    // 'QDesk.controller.command.scheduler.quartz.calendar.ViewCalendarAuditTrail',

    'QDesk.util.license.LicensedProductFeatures'
  ],

  constructor : function ( config )
  {
    var me = this;

    config = config || {};

    if ( !config.qdesk )
      Ext.Error.raise( 'Required config parameter missing: qdesk' );

    if ( !config.qdesk.connectionCtx )
      Ext.Error.raise( 'Required config parameter missing: qdesk.connectionCtx' );

    me.callParent( [ config ] );
  },

  init : function ()
  {
    var me = this;

    var connectionCtx = me.qdesk.connectionCtx;

    // CalendarsTab
    var view = me.getView();

    view.on( 'activate',
        function ()
        {
          if ( !view.isInitialized() )
          {
            me._bindEventHandlers( view );
            view.setInitialized( true );

            Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid', {
              connectionCtx : connectionCtx
            } ).execute();
          }
        } );

    me.callParent();
  },


  /**
   * Binds events of the specified view to their respective handlers.
   */
  _bindEventHandlers : function ( view )
  {
    var me = this;
    me._bindEventHandlersCalendarsGrid( view );
  },


  /**
   * Binds events of the embedded CalendarsGrid to their respective handlers.
   */
  _bindEventHandlersCalendarsGrid : function ( view )
  {
    var me = this;

    var licensedFeatures = QDesk.util.license.LicensedProductFeatures.featureSets.Quartz;

    var connectionCtx = me.qdesk.connectionCtx;
    var jvmAgentInfo = connectionCtx.getJvmAgentInfo();
    var schedulerInfo = connectionCtx.getSchedulerInfo();

    // var schedulerVersion = schedulerInfo.getSchedulerVersion();
    var jvmAgentReady = jvmAgentInfo.isReady();
    // var publicApiReady = schedulerInfo.isPublicApiReady();

    if ( licensedFeatures.Calendars && jvmAgentReady )
    {
      var calendarsGrid = view.down( '#calendarsGrid' );

      // refresh button
      calendarsGrid.on( 'refresh',
          function ()
          {
            me._refreshCalendars();
          } );

      calendarsGrid.on( 'addCalendar',
          function ()
          {
            me._addCalendar();
          } );

      calendarsGrid.on( 'deleteCalendar',
          function ( calendar )
          {
            me._deleteCalendar( calendar );
          } );

      calendarsGrid.on( 'editCalendar',
          function ( calendar )
          {
            me._editCalendar( calendar );
          } );

      calendarsGrid.on( 'cloneCalendar',
          function ( calendar )
          {
            me._cloneCalendar( calendar );
          } );

      calendarsGrid.on( 'viewCalendarAuditTrail',
          function ( calendar )
          {
            me._viewCalendarAuditTrail( calendar );
          } );
    }
  },


  _refreshCalendars : function ()
  {
    var me = this;

    var connectionCtx = me.qdesk.connectionCtx;

    Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid', {
      connectionCtx : connectionCtx
    } ).execute();
  },


  _addCalendar : function ()
  {
    var me = this;

    var connectionCtx = me.qdesk.connectionCtx;

    Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.AddCalendar', {
      connectionCtx : connectionCtx,
      /*
       * Upon success refresh the calendars tab.
       */
      success : function ()
      {
        Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid', {
          connectionCtx : connectionCtx
        } ).execute();
      }
    } ).execute();
  },


  _deleteCalendar : function ( calendar )
  {
    var me = this;

    var connectionCtx = me.qdesk.connectionCtx;

    Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.DeleteCalendar', {
      connectionCtx : connectionCtx,
      calendar : calendar,
      /*
       * Upon success refresh the calendars tab.
       */
      success : function ()
      {
        Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid', {
          connectionCtx : connectionCtx
        } ).execute();
      }
    } ).execute();
  },


  _editCalendar : function ( calendar )
  {
    var me = this;

    var connectionCtx = me.qdesk.connectionCtx;

    Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.EditCalendar', {
      connectionCtx : connectionCtx,
      calendarName : calendar.get( 'name' ),
      /*
       * Upon success refresh the calendars tab.
       */
      success : function ()
      {
        Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid', {
          connectionCtx : connectionCtx
        } ).execute();
      }
    } ).execute();
  },


  _cloneCalendar : function ( calendar )
  {
    var me = this;

    var connectionCtx = me.qdesk.connectionCtx;

    Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.CloneCalendar', {
      connectionCtx : connectionCtx,
      calendarName : calendar.get( 'name' ),
      /*
       * Upon success refresh the calendars tab.
       */
      success : function ()
      {
        Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.RefreshCalendarsGrid', {
          connectionCtx : connectionCtx
        } ).execute();
      }
    } ).execute();
  },


  _viewCalendarAuditTrail : function ( calendar )
  {
    var me = this;

    var connectionCtx = me.qdesk.connectionCtx;

    Ext.create( 'QDesk.controller.command.scheduler.quartz.calendar.ViewCalendarAuditTrail', {
      connectionCtx : connectionCtx,
      calendarName : calendar.get( 'name' )
    } ).execute();
  }
} );